#
# spec file for package gmp-ecm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_version 1
Name:           gmp-ecm
Version:        7.0.5
Release:        1.8
Summary:        Elliptic Curve Method for Integer Factorization
License:        GPL-3.0-only
Group:          Productivity/Scientific/Math
URL:            https://gitlab.inria.fr/zimmerma/ecm
Source0:        https://gitlab.inria.fr/zimmerma/ecm/uploads/89f6f0d65d3e980cef33dc922004e4b2/ecm-%{version}.tar.gz
# PATCH-FIX-UPSTREAM ecm-auxi.c.patch -- Add missing stdlib.h include
BuildRequires:  gmp-devel >= 5.0.0
BuildRequires:  m4

%description
GMP-ECM reads the numbers to be factored from stdin (one number on each
line) and requires a numerical parameter, the stage 1 bound B1. A reasonable
stage 2 bound B2 for the given B1 is chosen by default, but can be overridden
by a second numerical parameter. By default, GMP-ECM uses the ECM factoring
algorithm.

%package -n libecm%{so_version}
Summary:        Library for Elliptic Curve Integer Factorization
Group:          System/Libraries

%description -n libecm%{so_version}
Library for ecm. To use the library, you need to install ecm-devel, include
"ecm.h" in your source file and link with -lecm.

%package devel
Summary:        Development files for the gmp-ecm package
Group:          Development/Libraries/C and C++
Requires:       libecm%{so_version} = %{version}

%description devel
This package contains header files required when building applications which
use the libecm library.

%prep
%setup -q -n ecm-%{version}

%build
%configure \
%ifnarch x86_64
    --disable-sse2 \
%endif
    --disable-shellcmd \
    --enable-shared \
    --disable-static

%make_build

%install
%make_install

rm %{buildroot}/%{_libdir}/libecm.la

%check
%make_build check

%post -n libecm%{so_version} -p /sbin/ldconfig
%postun -n libecm%{so_version} -p /sbin/ldconfig

%files
%license COPYING COPYING.LIB
%doc AUTHORS NEWS README README.lib
%{_bindir}/ecm
%{_mandir}/man1/ecm.1%{?ext_man}

%files devel
%{_includedir}/ecm.h
%{_libdir}/libecm.so

%files -n libecm%{so_version}
%{_libdir}/libecm.so.*

%changelog
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 7.0.5:
  * migration to gitlab
  * https://gitlab.inria.fr/zimmerma/ecm/-/raw/git-7.0.5/ChangeLog
* Fri Jul 14 2017 jengelh@inai.de
- Fix RPM groups, summaries, and the condition for SSE2 disabling.
* Tue Jul 11 2017 ecsos@opensuse.org
- update to 7.0.4
  * fixed a bug in mpres_pow:
    https://gforge.inria.fr/tracker/?func=detail&atid=623&aid=20712&group_id=135
  * fixed a bug with P-1 or P+1 and small B2
  * improved portability (OS X, Windows, Cygwin, non GNU ld)
  * fixed make longcheck with out-of-source build
- update to 7.0.3
  * fixed compilation issue on powerpc64
- update to 7.0.2
  * fixed bug in P-1/P+1 stage 2 and -redc when -1/N mod R has
    less than n limbs
- update to 7.0.1
  * fixed efficiency issue with divisors of 2^n+/-1
  * allow for larger B1 values on Windows computers in batch mode
  * several fixes on Debian (FreeBSD, powerpc64)
  * fixed save files generated by gpu-ecm
  * fixed issue with gcc-5 (CC/CFLAGS from gmp.h were no longer
    used)
  * updated longlong.h file from GMP 6.1.0
  * fixed some compiler warnings
- update to 7.0.0
  * GMP-ECM is now thread-safe. In particular the "ecmfactor"
    binary can be called with say -t 17 to use 17 threads.
  * Added GPU code for Step 1 (command-line option -gpu).
  * Command-line option -param allows to choose the parametrization
    (valid values are 0, 1, 2, 3). Command-line option -sigma allows
    to choose the parameter. "-sigma i:s" is a shortcut to
    "-param i -sigma s". Use -param 0 to get historical Suyama
    parametrization.
  * The batch mode is now chosen with -param command-line option.
    The default parametrization depends on other command-line
    options.
  * For P-1 stage 2, by default the NTT code is always used.
  * Speedup in stage 2 with -no-ntt
  * New primality proving code with APRCL (contributed by
    David Cleaver) with --enable-aprcl (default=yes)
  * Removed some options that were unused or not tested
  (-n, -nn, -ve, -cofdec, -B2scale).
  * The configure --enable-shellcmd option was removed, and also
    the --enable-memory-debug configure option (now obsolete with
    valgrind).
  * The -b options was removed (breadth-first mode)
  * Improved source coverage (92.7%% of source code lines)
- remove patch ecm-auxi.c.patch because now in upstream
* Wed Mar 15 2017 sfalken@opensuse.org
- Added explicit BuildRequires: m4 to clear builderror in
  openSUSE:Factory
* Wed Sep 18 2013 idonmez@suse.com
- Initial release for build.opensuse.org
